@@ -1,11 +1,11 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-import requests
-import json
-
+from typing import Optional
 from urllib.parse import urljoin
 
+import requests
+
 
 class Lookyloo():
 
@@ -20,6 +20,13 @@ class Lookyloo():
         r = self.session.head(self.root_url)
         return r.status_code == 200
 
-    def enqueue(self, url: str) -> str:
-        response = self.session.post(urljoin(self.root_url, 'submit'), data=json.dumps({'url': url}))
+    def enqueue(self, url: Optional[str]=None, **kwargs) -> str:
+        if not url and 'url' not in kwargs:
+            raise Exception(f'url entry required: {kwargs}')
+
+        if url:
+            to_send = {'url': url, **kwargs}
+        else:
+            to_send = kwargs
+        response = self.session.post(urljoin(self.root_url, 'submit'), json=to_send)
         return urljoin(self.root_url, f'tree/{response.text}')
